==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/059create_anonymous_text_q.cc <==
// Create an anonymous text.
//
// $Id: 059create_anonymous_text_q.cc,v 1.3 1995/11/14 06:06:28 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "recipient.h"
#include "create_anonymous_text_q.h"
    
create_anonymous_text_question::create_anonymous_text_question(
					   Connection *conn,
					   const LyStr &message,
					   const DLList<Recipient> &recipients,
					   const DLList<Text_no>  &comment_to,
					   const DLList<Text_no>  &footnote_to)
    : question(conn), anon_text(0)
{
    Pix ix;
    prot_a_LyStr   s;
    int len = recipients.length() + comment_to.length() + footnote_to.length();

    s << ref_no() << " 59 ";
    s.append_hollerith(message);
    s << ' ' << len << " { ";
    for (ix = recipients.first(); ix != 0; recipients.next(ix))
	s << (recipients(ix).is_carbon_copy() ? "1 " : "0 ")
	    << recipients(ix).recipient() << ' ';

    for (ix = footnote_to.first(); ix != 0; footnote_to.next(ix))
	s << "4 " << footnote_to(ix) << ' ';

    for (ix = comment_to.first(); ix != 0; comment_to.next(ix))
	s << "2 " << comment_to(ix) << ' ';

    s << "}\n";

    port->send_question(s);
}


create_anonymous_text_question::~create_anonymous_text_question()
{
}


void
create_anonymous_text_question::parser(prot_a_LyStr& str)
{
    anon_text = str.stol();
    state = st_ok;
    deallocate_refno();
}


Text_no
create_anonymous_text_question::result()
{
    return anon_text;
}

==> kom%2B%2B-0.7.post.4.tar.gz: kom++-0.7.post.4/libconnection/059create_anonymous_text_q.cc <==
// Create an anonymous text.
//
// $Id: 059create_anonymous_text_q.cc,v 1.4 1999/11/11 23:48:39 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <config.h>

#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "recipient.h"
#include "create_anonymous_text_q.h"
    
create_anonymous_text_question::create_anonymous_text_question(
					   Connection *conn,
					   const LyStr &message,
					   const vector<Recipient> &recipients,
					   const vector<Text_no>  &comment_to,
					   const vector<Text_no>  &footnote_to)
    : question(conn), anon_text(0)
{
    typedef vector<Recipient>::const_iterator RI;
    typedef vector<Text_no>::const_iterator TI;

    prot_a_LyStr   s;
    int len = recipients.size() + comment_to.size() + footnote_to.size();

    s << ref_no() << " 59 ";
    s.append_hollerith(message);
    s << ' ' << len << " { ";
    for (TI iter = footnote_to.begin(); iter != footnote_to.end(); ++iter)
	s << "4 " << *iter << ' ';

    for (TI iter = comment_to.begin(); iter != comment_to.end(); ++iter)
	s << "2 " << *iter << ' ';

    for (RI iter = recipients.begin(); iter != recipients.end(); ++iter)
	s << ((*iter).is_carbon_copy() ? "1 " : "0 ")
	  << (*iter).recipient() << ' ';

    s << "}\n";

    port->send_question(s);
}


create_anonymous_text_question::~create_anonymous_text_question()
{
}


void
create_anonymous_text_question::parser(prot_a_LyStr& str)
{
    anon_text = str.stol();
    state = st_ok;
    deallocate_refno();
}


Text_no
create_anonymous_text_question::result()
{
    return anon_text;
}
